#
# spec file for package texinfo4
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           texinfo4
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  help2man
BuildRequires:  libbz2-devel
BuildRequires:  libzio-devel
BuildRequires:  ncurses-devel
BuildRequires:  perl-gettext
BuildRequires:  zlib-devel
Version:        4.13a
Release:        lp152.5.3.1
%global         version_t2h 1.82
%global         version_t2r 2.0
Summary:        Old version of texinfo 4, a toolset to create docs from texinfo sources
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          Productivity/Publishing/Texinfo
URL:            http://www.texinfo.org
PreReq:         %{install_info_prereq}
Provides:       texi2html4 = %{version_t2h}
Provides:       texi2roff4 = %{version_t2r}
#Conflicts:	texinfo
#Conflicts:	texi2html
#Conflicts:	texi2roff
%if %suse_version > 1220
Requires:       latex2html
Requires:       makeinfo4
Requires:       perl-Text-Unidecode
Requires:       perl-gettext
Requires:       texlive-bibtex
Requires:       texlive-latex
Requires:       texlive-makeindex
Requires:       texlive-pdftex
Requires:       texlive-tex
Requires:       texlive-texinfo
%endif
Source0:        texinfo-%{version}.tar.bz2
Source1:        texi2html-%{version_t2h}.tar.bz2
# texinfo.org: the domain is expired.
# http://texinfo.org/texi2roff/texi2roff-%%{version_t2r}.tar.bz2
Source2:        texi2roff-%{version_t2r}.tar.bz2
Source10:       info-dir
Patch:          texinfo-4.12.dif
Patch1:         texi2html-1.78.dif
Patch2:         texi2roff-2.0.dif
Patch3:         texi2roff.patch.bz2
Patch4:         texinfo-4.12-zlib.patch
Patch5:         texinfo-4.8-echo.patch
Patch6:         texi2roff-2.0-gcc4.patch
Patch7:         texinfo-4.13a-bug640417.diff
Patch8:         texinfo-4.13a-bug713517.diff
Patch9:         automake-1.12.patch
Patch10:        texinfo-4.13a-bug788574.diff
Patch12:        texinfo4.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package is only for building lilypond documentation in the
build service. Please don't install
Aggregated with texinfo in this package is texi2html and texi2roff.

%package -n info4
Summary:        Old version of the "info" manual browser
License:        GPL-3.0-or-later
Group:          Productivity/Publishing/Texinfo
PreReq:         bash

%description -n info4
This package is only for building lilypond documentation in the
build service. Please don't install

%package -n makeinfo4
Summary:        Old version of the texinfo->info file converter
License:        GPL-3.0-or-later
Group:          Productivity/Publishing/Texinfo
Provides:       texinfo:/usr/bin/makeinfo
Suggests:       texinfo4

%description -n makeinfo4
This package is only for building lilypond documentation in the
build service. Please don't install

%prep
rm -rf texi2html-%{version_t2h} texi2roff-%{version_t2r}
%setup -q -b 1 -b 2 -n texinfo-4.13
%patch4 -p0 -b .zlib
%patch5 -p0 -b .echo
%patch7 -p1 -b .size_t
%patch8 -p0 -b .egrep
%patch9 -p1
%patch10 -p0 -b .appendix
%patch -p0
mkdir -p .backup
cp -v util/texi2pdf util/pdftexi2dvi .
%patch12
cp -v util/texi2pdf util/pdftexi2dvi .backup
cp -v texi2pdf pdftexi2dvi util/
pushd ../texi2html-%{version_t2h}
%patch1 -p0
popd
pushd ../texi2roff-%{version_t2r}
%patch3 -p0 -b .Bader
%patch2 -p0
%patch6 -p1
popd

%build
    HOST=%{_target_cpu}-suse-linux
    CFLAGS="%{optflags} -pipe"
    LDFLAGS=""
    CC=gcc
    export CFLAGS LDFLAGS CC
    export SUSE_ASNEEDED=0
    AUTOPOINT=true autoreconf -fi
    ./configure --build=$HOST		\
	--prefix=%{_prefix}		\
	--mandir=%{_mandir}		\
	--datadir=%{_datadir}		\
	--infodir=%{_infodir}		\
	--without-included-gettext	\
	--enable-nls			\
	--program-suffix=4

    PATH=${PWD}/makeinfo:${PWD}/util:$PATH
    export PATH
    make %{?_smp_mflags};
pushd ../texi2html-%{version_t2h}
    cp ../texinfo-4.13/build-aux/config.{guess,sub} .
    ./configure --build=$HOST		\
	--prefix=%{_prefix}		\
	--mandir=%{_mandir}		\
	--datadir=%{_datadir}		\
	--infodir=%{_infodir}		\
	--without-included-gettext	\
	--enable-nls			\
	--program-suffix=4
    make %{?_smp_mflags};
popd
pushd ../texi2roff-%{version_t2r}
    rm -f texi2roff
    make %{?_smp_mflags};
popd

%install
    export SUSE_ASNEEDED=0
    make DESTDIR=%{buildroot} \
	infodir=%{_infodir}	   \
	htmldir=%{_defaultdocdir}/texi2html4 install
    rm -f %{buildroot}%{_infodir}/info.info*
    mkdir -p %{buildroot}/sbin
    mv %{buildroot}%{_bindir}/install-info4 %{buildroot}/sbin/
    ln -sf ../../sbin/install-info4 %{buildroot}%{_bindir}/install-info4
    mkdir -p %{buildroot}%{_infodir}
    install -m 644 %{S:10}       %{buildroot}%{_infodir}/dir
pushd ../texi2html-%{version_t2h}
    make DESTDIR=%{buildroot} \
	infodir=%{_infodir}	   \
	texinfohtmldir=%{_defaultdocdir}/texi2html4 install
    install -m 644 README        %{buildroot}%{_defaultdocdir}/texi2html4/
    install -m 644 NEWS          %{buildroot}%{_defaultdocdir}/texi2html4/
    install -m 644 COPYING       %{buildroot}%{_defaultdocdir}/texi2html4/
popd
pushd ../texi2roff-%{version_t2r}
    doc=%{_defaultdocdir}/texi2roff4
    mv texi2roff texi2roff4
    mv texi2index texi2index4
    mv texi2roff.1 texi2roff4.1
    install -m 755 texi2roff4     %{buildroot}%{_bindir}/
    install -m 755 texi2index4    %{buildroot}%{_bindir}/
    install -m 644 texi2roff4.1   %{buildroot}%{_mandir}/man1/
    mkdir -p                     %{buildroot}${doc}
    install -m 644 Readme        %{buildroot}${doc}
    install -m 644 copyright     %{buildroot}${doc}
popd

install -v .backup/texi2pdf %{buildroot}%{_bindir}/texi2pdf4
install -v .backup/pdftexi2dvi %{buildroot}%{_bindir}/pdftexi2dvi4

rm -rf %{buildroot}%{_datadir}/locale
rm -rf %{buildroot}%{_datadir}/info
mv %{buildroot}%{_datadir}/texi2html %{buildroot}%{_datadir}/texi2html4
mv %{buildroot}%{_datadir}/texinfo %{buildroot}%{_datadir}/texinfo4

%fdupes -s %{buildroot}%{_mandir}

%if 1 == 0
%post
%install_info --info-dir=%{_infodir} %{_infodir}/texinfo4.gz
%install_info --info-dir=%{_infodir} %{_infodir}/texi2html4.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/texinfo4.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/texi2html4.info.gz

%post -n info4
%install_info --info-dir=%{_infodir} %{_infodir}/info-stnd.info4.gz

%postun -n info4
%install_info_delete --info-dir=%{_infodir} %{_infodir}/info-stnd4.info.gz
%endif

%files
%defattr(-, root, root)
%dir %{_defaultdocdir}/texi2html4
%dir %{_defaultdocdir}/texi2roff4
%doc ABOUT-NLS AUTHORS INTRODUCTION NEWS README TODO
%license  COPYING
%doc doc/texinfo.tex doc/txi-*.tex
%doc %{_defaultdocdir}/texi2html4/*
%doc %{_defaultdocdir}/texi2roff4/*
%{_bindir}/pdftexi2dvi4
%{_bindir}/texi2dvi4
%{_bindir}/texi2html4
%{_bindir}/texi2index4
%{_bindir}/texi2pdf4
%{_bindir}/texi2roff4
%{_bindir}/texindex4
#%%{_infodir}/texinfo*.gz
#%%{_infodir}/texi2html*.gz
%{_mandir}/man1/pdftexi2dvi4.1.gz
%{_mandir}/man1/texi*.1.gz
%{_mandir}/man5/texinfo4.5.gz
%{_datadir}/texinfo4
%{_datadir}/texi2html4

%files -n makeinfo4
%defattr(-,root,root)
%{_bindir}/makeinfo4
%{_mandir}/man1/makeinfo4.1.gz

%files -n info4
%defattr(-,root,root)
#%%config(noreplace) %%verify(not md5 size mtime) %%{_infodir}/dir
/sbin/install-info4
%{_bindir}/install-info4
%{_bindir}/info4
%{_bindir}/infokey4
#%%{_infodir}/info-stnd.info*
%{_mandir}/man1/info4.1*
%{_mandir}/man1/infokey4.1*
%{_mandir}/man1/install-info4.1*
%{_mandir}/man5/info4.5*

%changelog
* Wed Aug 19 2020 Dave Plater <davejplater@gmail.com>
- Remove links sub package and generate links in lilypond build.
* Thu May  7 2020 Dave Plater <davejplater@gmail.com>
- Added links package to help lilypond-doc build use this package.
* Thu Nov 22 2018 Jan Engelhardt <jengelh@inai.de>
- Update summaries. Remove redundant %%clean section. Replace old
  $RPM_* shell vars.
* Wed Nov 21 2018 schwab@suse.de
- config-guess-sub-update.patch: remove
- copy config.guess, config.sub from texinfo to texi2html sources
* Sun Jul 12 2015 davejplater@gmail.com
- Created texinfo4 package from 0penSUSE:13.2 texinfo poackage to
  enable lilypond's documentation to build again. bnc#936870
* Mon May  6 2013 schwab@linux-m68k.org
- Don't package info.info, already part of emacs-info
* Tue Feb 12 2013 schwab@suse.de
- config-guess-sub-update.patch:
  Update config.guess/sub for aarch64
* Tue Nov 20 2012 werner@suse.de
- Use latest CVS version for the last patch
* Mon Nov 19 2012 werner@suse.de
- Be aware that characters of appendix numbering requires a ASCII
  null if used as string (bnc#788574)
* Sat Oct  6 2012 coolo@suse.com
- remove prereq on library names
* Tue Jul 17 2012 werner@suse.de
- Split off makeinfo as separate package to independed from
  TeXLive
* Tue Jul 10 2012 werner@suse.de
- Make it build with latest TeXLive 2012 with new package layout
  + Add missed TeX
  + Also bibtex and makeindex are used by texi2dvi
  + Add some requires to make the texi2* scripts work
* Tue May 29 2012 puzel@suse.com
- fix build with automake-1.12
  - add: automake-1.12.patch
* Wed Feb  8 2012 werner@suse.de
- Work around dully check script of obs
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Fri Sep  2 2011 werner@suse.de
- Fix UTF-8 range problem of a grep call (bnc#713517)
* Mon May  2 2011 ke@suse.de
- Enhance package description and provide meta info about makeinfo; thus
  you can find this tool more easily with the yast package search..
* Wed Nov 10 2010 meissner@suse.de
- SUSE_ASNEEDED=0 to fix PowerPC build (optimizes
  away the -lz -lbz2 otherwise)
* Wed Sep 22 2010 giecrilj@stegny.2a.pl
- Fix variable types (bnc#640417)
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Sun Dec  6 2009 jengelh@medozas.de
- enable parallel building
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Fri Jul  3 2009 werner@suse.de
- Add provides for texi2html and texi2roff (bnc#469300)
- Update to texi2html 1.82 (2009-01-05)
  * Add new hooks for user functions, for simple @-commands, and at the start and
    end of special regions.
  * Don't use unidecode on unicode characters that are known not to have a good
    transliteration.  This corresponds with characters with an @-command that
    don't have a transliteration, like @exclamdown...
  * handle @alias, @quote*, @guillem*, @textdegree, @allowcodebreaks,
    @fonttextsize, @hyphenation, @click, @clickstyle, @click, @arrow,
    @clicksequence, @geq, @leq, @*headingmarks, @*footingmarks, @smallquotation,
    @ogonek.
    Handle @columnfractions and row prototypes in @multitable better.
  * @documentlanguage is used to set the language each time it is seen (except
    if the language was set on the command line).
  * new option --css-ref, generate reference to a CSS URL.
  * new option --transliterate-file-names, produce file names in ASCII
    transliteration (set in the default case).
  * --no-monolithic is reenabled.
  * @, followed by an argument without brace is now handled. Report from
    Jorge Barros de Abreu.
  * @, is kept with --macro-expand.
  * @math is more compatible with makeinfo/texi2dvi when no external program
    is used. Using tex4ht for html generation should also lead to a correct
    result.
  * Handle right @end block commands followed by something else than a
    spacing character.
  * Remove trailing end of line in @html block.
  * @itemize should produce bullets by default. Report from Reinhold Kainhofer.
  * handle frame files like other files. Report from Reinhold Kainhofer.
- Update to texinfo 4.13a (18 September 2008)
  * A reference card for Texinfo is now available, in doc/refcard.  For
    convenience, preformatted PDF's for letter-size and A4 paper are included.
  * makeinfo:
    . new option --internal-links for HTML output, to write a tsv file
    mapping indexed/toc terms to links, for easy reference from external
    documents.
    . - as an input file name reads standard input.
  * info:
    . support for multibyte encodings such as UTF-8.
    . new option --show-malformed-multibytes, to display malformed multibyte
    sequences.
    . new environment variable INFO_MAN_COMMAND sets the name of man binary
    (use it if you a need to override PATH settings).
  * install-info:
    . bug fix: support names with embedded periods (e.g., config.status) again.
  * Distribution:
    . autoconf 2.63.
* Sun Jun 15 2008 schwab@suse.de
- Update to texinfo 4.12.
  * Language:
    . new commands @clicksequence, @click, and @clickstyle for documenting
    GUI sequences, and @arrow for the default glyph used.
    . new commands @geq{} and @leq{} for the normal >= and <= relations.
  * install-info:
    . lzma compression supported.
    . Much work towards compatibility with Debian's independent
    implementation.  Changes in behavior:
  - new entries are formatted to start at column 34 by default.
  - existing entries are replaced by default.
  - new sections are alphabetized among existing sections.
  - if an entry being removed is the last one in a section, the
  section is also removed.
    . Also many new options:
  - -section REGEX TITLE.
  - -no-indent: disable formatting of new entries.
  - -menuentry, --name: specify left-hand side of an entry.
  - -dry-run: alias for --test.
  - -regex REGEX: renamed from --section regex, adds to all sections
  matching REGEX by default.
  - -add-once: add only to first specified or matching section.
  - -align COL: start description at column COL.
  - -calign COL: start continuation lines in description at COL.
  - -max-width COL: wrap the description at COL.
    . New section in the Texinfo manual describing all this.
  * Info:
    Our goal with these changes to the default interface is to make Info
    documents more easily and quickly readable, especially by non-experts.
    . the PageUp and PageDown keys move through the whole document by
    default, instead of just the current node.
    . the h command shows the basic help, and H starts the Info tutorial.
    . the newly-bound x command deletes the current window, e.g., within help.
    . the scroll-step variable is set to 1 by default, for smooth scrolling.
    . the cursor-movement-scrolls-p variable is set to 1 by default, so
    link searches look through the whole document.
    . regular expression searches are supported, and are the default for
    both regular and incremental searches.
    . the new R command toggles between regexp and literal-string searches.
    . the new variable scroll-last-node controls scrolling at the end of
    the last node; by default, it now simply reports there are no more
    nodes.  To restore the old behavior, set scroll-last-node=Scroll.
    . the precise line number specified in index entries is used if available.
    . --usage=info shows usage for standalone Info.
    . lzma compression supported.
  * Distribution:
    . language support for no removed/renamed to nb, per Norwegian translators.
    . new translation: es.
    . bug fixes in make check (and elsewhere).
    . gettext 0.17, automake 1.10.1, autoconf 2.62.
* Mon Mar 10 2008 werner@suse.de
- Update to texinfo version 4.11 (4.10 was omitted)
  * Language:
  . @documentlanguage now supports an optional country code
    specification after the language code, a la gettext.
  . new command @allowcodebreaks controls breaks at _ and - within @code.
  . new command @frenchspacing controls spacing after sentences.
  . new command @fonttextsize allows changing body text font size to 10pt.
  . new command @textdegree{} produces the normal degrees symbol.
  . new command @thischapternum can be used in TeX headers/footers.
  . new commands for quotes: @quotedblleft @quotedblright
    @quoteleft @quoteright  @quotedblbase @quotesinglbase
    @guillemetleft @guillemetright @guilsinglleft @guilsinglright.
  . new option @set txicodequoteundirected produces an undirected quote
    in code and example output, instead of the regular right quote.
  . new option @set txicodequotebacktick produces a grave accent in
    code and example output, instead of the regular left quote.
  * makeinfo:
  . The @documentlanguage locale is used to translate various document strings.
  . --enable-encoding is now the default, meaning Info and plain text
    output use 8-bit characters given a supported @documentencoding.
  . new option --css-ref=URL for creating a stylesheet <link> in HTML output.
  . new option --transliterate-file-names to use a reduction-to-ASCII
    algorithm for split HTML file names, useful for non-Latin-based languages.
  . @enddots{} outputs three dots instead of four, for consistency with
    texinfo.tex.
  . the Local Variables coding: setting written by --enable-encoding now
    comes at the very end, after the tags table, so that Emacs can find
    it in more cases.
  . @allow-recursion (never documented) is deprecated and produces a warning.
  . @quote-args (never documented) is now the default behavior.
  . centering and such take account of character widths.
  . the --reference-limit option is now a no-op.
  . improvements to XML and Docbook output and the DTD.
  * texinfo.tex:
  . @thissection can now be used in custom headings, and @thischapter
    works reliably even without @set chapternewpage.  Custom headings
    have additional flexibility as well.
  * texi2dvi:
  . pdftexi2dvi is a new wrapper to `texi2dvi --pdf', equal to texi2pdf,
    for the sake of AUC-TeX which prepends `pdf' to the compilation
    command when requested to produce PDF.
  * info:
  . look for info files in the current directory first, by default.
  . when calling man, use -a if no explicit section is found.
  . avoid showing the top(1) man page for nonexistent info files.
  * install-info:
  . new options --section-regex, --remove-exactly, --debug, --test.
  * Distribution:
  . autoconf 2.60, automake 1.10, gettext 0.16.1.
  . gettext support now [external].
  . new translations: hu (Hungarian), rw (Kinyarwandan), vi (Vietnamese).
  . most common sources imported from gnulib.
* Wed Jul 11 2007 werner@suse.de
- Update to texinfo version 4.9
  * GPLv3.
  * texi2dvi:
    . new mode --build=tidy which supports compilation in a separate
    directory, where intermediate files are preserved.
    . new option --build-dir, to specify where the tidy build will take
    place, either locally or globally.  This allows avoiding the clutter
    while preserving auxiliary files.
    . new support for AUC-TeX: texi2dvi (weakly) supports arguments a la
    TeX such as `\nonstopmode\input{file.tex}'.
    . new options --ps and --dvipdf, useful especially for pstricks documents.
    . new option --src-specials, passed to TeX.
    . pdftexi2dvi is a new wrapper to `texi2dvi --pdf', equal to texi2pdf,
    for the sake of AUC-TeX which prepends `pdf' to the compilation
    command when requested to produce PDF.
  * texinfo.tex:
    . Latin1, Latin2, Latin9, and UTF-8 are supported as well as Computer
    Modern can manage.
    . png and jpg images supported in pdf output.
    . new Russian, Serbian, and Ukrainian translations for texinfo.tex:
    txi-ru.tex, txi-sr.tex, txi-uk.tex.
    . section names with \ characters work properly in pdf outlines.
    . have .toc files use @ as the escape character, instead of \.
- Update to texi2html version 1.78
  * Transliterate accented characters in file names. Use Text::Unidecode
    if detected.
  * Handle @frenchspacing, @tie, @indent, @setcontentsaftertitlepage,
    @setshortcontentsaftertitlepage and the obsolete @allow-recursion
    and @quote-arg.
  * With book style the Table of Contents is put where it is set.
  * Use more numeric entities, especially for accented letters.
  * The `examples' directory now contains an init file for Mediawiki output.
    Mediawiki is the GPL'd wiki used by Wikipedia.
  * new init file tex4ht.init. With this init file, httex or htlatex from
    tex4ht is used to format @tex and @math.
  * Init files now have a chance to override all file names, rather than just
    page names.
  * Put the images under a double licence by adding back their original GPL
    licence.
  * If SIMPLE_MENU is true the menu is simply enclosed in a preformatted
    environment.
  * The user can bypass the texi2html functions and provide his own function
    to do things similar that what is done for interfacing with LaTeX2HTML
    or tex4ht.
  * LaTeX2HTML stuff is moved out of texi2html.pl, to T2h_l2h.pm.
  * Add $USER and $DATE variables to override the defaults detected for the
    footer.
  * $TOP_FILE and $TOC_FILE are only set if set by the user. The elements
    file names are in the hash reference $Texi2HTML::THISDOC{'filename'}
    for use in init files.
  * The API for image, normal_text, paragraph and node_file_name has changed.
  * The $ENCODING variable is deprecated, replaced by $ENCODING_NAME
    and $OUT_ENCODING.
  * utf8 is used as default out file encoding. This should allow for utf8
    translations for languages which cannot use @-commands for non ascii
    characters.
  * Use entities for ``, '', ---, -- and quotes used for some formatting
    @-commands if $USE_ISO is set.
  * don't set unset MENU-ENTRY-NAME if it is similar with the NODE-NAME,
    it is useless as it is a construct that shouldn't happen.
  * avoid menu entry and description redundancy in the formatting function
    and not in the main program.
  * accept - in @-command names (compatibility with makeinfo)
  * in user-defined macro arguments a comma in brace is escaped (compatibility
    with makeinfo from texinfo 4.8.90)
  * don't add the section title to the html title when the document isn't split
  * When the file extension is set to the empty string, a trailing `.' will not
    be automatically added to file names.
  * The texi2html script is now created by make and not configure.
  * It is possible to build the translation files from outside of the
    build directory.
  * When configure detects that no Data::Dumper is present, the build scripts
    will simply copy the files instead of breaking.
  * remove handling of quotation second arg, quotation has only one arg.
  * handle nested ifset/ifclear.
  * Improved handling of @sc and @centerchap.
  * More flexible normal_text.
  * style_stack really contains the formatting @-commands.
  * caching of html generated by latex2html reenabled.
  * when not split and no section navigation is output, the about page and
    navigation direction are not output for all the elements.
* Mon Mar 26 2007 rguenther@suse.de
- Add libbz2-devel, ncurses-devel and zlib-devel BuildRequires
- Exchange libzio for libzio-devel BuildRequires
* Mon Feb 19 2007 werner@suse.de
- Avoid array subscript below array bounds (bug #246740)
* Fri Nov 10 2006 werner@suse.de
- Fix buffer overflow in texi2dvi (bug #214920)
* Mon Jul 24 2006 adrian@suse.de
- add libzio as PreReq for info
* Fri Jun 16 2006 werner@suse.de
- Re-enable texi2pdf because now tetex does not install this
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 werner@suse.de
- Add missing sym link to file list
* Thu Oct  6 2005 werner@suse.de
- Use directory for the base of temporary index files (bug #120577)
* Thu Mar 24 2005 uli@suse.de
- fixed to build with GCC4
* Thu Feb 10 2005 werner@suse.de
- Update to next bug fix release 1.76 of texi2html
* Tue Feb  1 2005 werner@suse.de
- Update to bug fix release 1.74 of texi2html
* Thu Jan 27 2005 werner@suse.de
- Fix texi2html to not loop around on broken texi files
- Remove texi2pdf from texinfo file list due already part of
  tetex
* Wed Jan 26 2005 schwab@suse.de
- Reenable strict aliasing.
* Tue Jan 25 2005 werner@suse.de
- Move texi2html version to 1.72
- Update texinfo version to 4.8
* Mon Oct 18 2004 ro@suse.de
- drop no locale support, nb is already there
* Mon Aug  9 2004 werner@suse.de
- Info: check remaining buffer size before printing into echo area
* Fri Jul  2 2004 mfabian@suse.de
- apply makeinfo.patch received from Karl Berry
  <karl@freefriends.org> fixing the problem that makeinfo 4.7
  could not process groff.texinfo anymore. See
  http://lists.gnu.org/archive/html/bug-texinfo/2004-04/msg00026.html
  http://article.gmane.org/gmane.comp.tex.texinfo.bugs/2019/
* Wed Apr 21 2004 werner@suse.de
- Use libzio together with zlib and libbz2 to support bz2 info
  files to avoids pipe()/fork()/execve() calls in install-info.
* Mon Apr 19 2004 werner@suse.de
- Be sure that texi2html find all required tools
* Fri Apr 16 2004 werner@suse.de
- Update to texinfo 4.7
- Use -fno-strict-aliasing
* Sun Mar 14 2004 schwab@suse.de
- Fix uses of snprintf and gzFile.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Wed Dec 10 2003 werner@suse.de
- Update to texinfo 4.6
* Tue May 20 2003 ro@suse.de
- fix filelist: package files in /usr/share/texinfo
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Sun Mar  9 2003 kukuk@suse.de
- Add zlib to info PreRequires [Bug #24954]
* Tue Feb 11 2003 kukuk@suse.de
- Branch off info sub package
- Add /usr/share/info/dir
* Sat Feb  8 2003 kukuk@suse.de
- Remove PreRequire for gzip, link against zlib instead (patched
  based on version from RH)
* Sat Feb  8 2003 ro@suse.de
- fixed pre/post install scripts
* Fri Feb  7 2003 ro@suse.de
- removed self-prereq again
* Thu Feb  6 2003 aj@suse.de
- Use install_info.
- Update to texinfo 4.5.
* Wed Jan 22 2003 werner@suse.de
- Request gzip before installing (bug #22992)
* Fri Aug 30 2002 werner@suse.de
- Add a warning on missed programs and say what todo (bug #18642)
* Mon Jun 17 2002 schwab@suse.de
- Update to texinfo 4.2.
* Thu Mar  7 2002 schwab@suse.de
- Update to texinfo 4.1.
* Wed Feb 13 2002 schwab@suse.de
- Fix verbose message of texi2dvi.
* Thu Jan 24 2002 okir@suse.de
- fixed tempfile races in texindex (moved all tempfiles
  into a subdirectory of /tmp).
* Wed Jan 16 2002 schwab@suse.de
- Fix bad free in "makeinfo --html".
* Tue Jun 12 2001 schwab@suse.de
- Fix directive inside macro call.
* Thu Apr 12 2001 werner@suse.de
- Use CVS snapshot of texi2html which works on glibc texinfo code
* Thu Apr 12 2001 ro@suse.de
- fixed glossary for texi2html
* Wed Apr 11 2001 werner@suse.de
- Update of texi2html and texi2roff
* Thu Sep 28 2000 werner@suse.de
- Move /usr/bin/install-info to /sbin/install-info and
  set backward compatibility symlink.
* Wed May 31 2000 werner@suse.de
- use rpm macros for common paths
* Mon Feb 28 2000 werner@suse.de
- Fix segmentation fault (close bug #1911)
* Thu Feb  3 2000 werner@suse.de
- Fixed de.po
* Wed Feb  2 2000 werner@suse.de
- Remove Makefile.Linux
- /usr/man -> /usr/share/man
- /usr/info -> /usr/share/info (man pages and main for info program)
- Install info pages of texinfo
* Wed Dec  1 1999 werner@suse.de
- small changes
* Mon Nov 29 1999 ke@suse.de
- update: version 4.0 (#600).
- use BuildRoot.
- install COPYRIGHT, etc.
- don't disable NLS.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jan 11 1999 ro@suse.de
- info/terminal.c : TIOCGETC and TIOCGLTC are defined on alpha,
    but we can't access tchars and ltchars strutures,
    so undef both
    use tcgetattr and cfgetospeed to determine output
    speed
* Fri Jul 17 1998 werner@suse.de
- check exit satus of mkdir for temp directories
* Tue Oct 14 1997 ro@suse.de
- update to 3.12
* Tue Oct 14 1997 ro@suse.de
- ready for autobuild
* Fri Oct 10 1997 florian@suse.de
- update to texinfo 3.11
* Sun Jun 22 1997 florian@suse.de
- add debian-changes to support ANSI-cursor movements
- add texi2html 1.51
- add texi2roff 2.0
* Sun Apr 13 1997 florian@suse.de
- cosmetic changes, just done in preparation for glibc
* Thu Jan  2 1997 florian@suse.de
- Update auf neue Version 3.9.
